@@ -7,8 +7,9 @@ use Dancer::Config 'setting';
 use Getopt::Long;
 
 my $options = {
-    port => setting('port'),
-    daemon => setting('daemon'),
+    port        => setting('port'),
+    daemon      => setting('daemon'),
+    confdir     => setting('confdir') || setting('appdir'),
     environment => 'development',
 };
 
@@ -19,25 +20,30 @@ sub arg_to_setting {
 
 sub process_args {
     my $help = 0;
-    GetOptions( 
+    GetOptions(
         'help'          => \$help,
         'port=i'        => sub { arg_to_setting(@_) },
         'daemon'        => sub { arg_to_setting(@_) },
         'environment=s' => sub { arg_to_setting(@_) },
+        'confdir=s'     => sub { arg_to_setting(@_) },
+        'restart=s'     => sub { arg_to_setting( auto_reload => $_[1] ) },
     ) || usage_and_exit();
 
     usage_and_exit() if $help;
 }
 
 sub usage_and_exit { print_usage() && exit(0) }
+
 sub print_usage {
-print <<EOF
+    print <<EOF
 \$ ./yourdancerapp.pl [options]
 
  Options:
    --daemon             Run in background (false)
    --port=XXXX          Port number to bind to (3000)
+   --confdir=PATH       Path the config dir (appdir if not specified)
    --environment=ENV    Environement to use (development)
+   --restart=1|0        Should we restart the application between each request
    --help               Display usage information
 
 OPTIONS
@@ -53,9 +59,26 @@ during the development phase.
 This lets you change the port number to use when running the process. By
 default, the port 3000 will be used.
 
+--confdir=PATH
+
+By default, Dancer looks in the appdir for config files (config.yml and
+environments files). You can change this with specifying an alternate path to
+the configdir option.
+
+Dancer will then look in that directory for a file config.yml and the
+appropriate environement configuration file.
+
+If not specified, confdir points to appdir.
+
 --environment=ENV
 
-THIS OPTIONS IS NOT SUPPORTED YET 
+Which environment to use. By default this value is set to development.
+
+--restart
+
+Set the value of the B<auto_reload> setting. Usefull when you want to switch
+this setting for a test without changing the value in your configurations
+file.
 
 EOF
 }
