@@ -41,11 +41,8 @@ sub register($&) {
     my ($keyword, $code) = @_;
     my $plugin_name = caller();
 
-    $keyword =~ /^[a-zA-Z_]+[a-zA-Z0-9_]*$/
-      or croak "You can't use '$keyword', it is an invalid name (it should match ^[a-zA-Z_]+[a-zA-Z0-9_]*$ )";
-
-    if (grep { $_ eq $keyword } map { s/^(?:\$|%|&|@|\*)//; $_ } (@Dancer::EXPORT, @Dancer::EXPORT_OK)) {
-        croak "You can't use '$keyword', this is a reserved keyword";
+    if (grep { $_ eq $keyword } @Dancer::EXPORT) {
+        croak "You can't use $keyword, this is a reserved keyword";
     }
     while (my ($plugin, $keywords) = each %$_keywords) {
         if (grep { $_->[0] eq $keyword } @$keywords) {
