@@ -47,7 +47,8 @@ sub _find_content_type {
         $content_types{$request->{accept_type}} = 1;
     }
 
-    $content_types{'application/json'} = 0;
+    $content_types{'application/json'} = 0
+      unless defined $content_types{'application/json'};
 
     return [
         sort { $content_types{$b} <=> $content_types{$a} }
@@ -57,15 +58,16 @@ sub _find_content_type {
 
 sub serialize {
     my ($self, $entity) = @_;
-    my $request = Dancer::SharedData->request;
+    my $request    = Dancer::SharedData->request;
     my $serializer = $self->_load_serializer($request);
     return $serializer->serialize($entity);
 }
 
 sub deserialize {
-    my ($self, $content, $request) = @_;
+    my ($self, $content) = @_;
+    my $request    = Dancer::SharedData->request;
     my $serializer = $self->_load_serializer($request);
-    return $serializer->deserialize($content, $request);
+    return $serializer->deserialize($content);
 }
 
 sub content_type {
@@ -83,10 +85,10 @@ sub _load_serializer {
 
     my $content_types = $self->_find_content_type($request);
     foreach my $ct (@$content_types) {
-        if ( exists $serializer->{$ct} ) {
+        if (exists $serializer->{$ct}) {
             my $module = "Dancer::Serializer::" . $serializer->{$ct};
-            if ( !exists $loaded_serializer->{$module} ) {
-                if ( Dancer::ModuleLoader->load($module) ) {
+            if (!exists $loaded_serializer->{$module}) {
+                if (Dancer::ModuleLoader->load($module)) {
                     my $serializer_object = $module->new;
                     $loaded_serializer->{$module} = $serializer_object;
                 }
