@@ -4,52 +4,37 @@ use strict;
 use warnings;
 
 use Dancer::Cookies;
-use Dancer::Config 'setting';
-
-# Table to map supported engines with their module
-my $ENGINES = {
-    yaml      => 'Dancer::Session::YAML',
-    memcached => 'Dancer::Session::Memcached',
-};
+use Dancer::Engine;
 
 # Singleton representing the session engine class to use
 my $ENGINE = undef;
 sub engine {$ENGINE}
 
-sub set_engine {
-    my ($engine) = @_;
-    $ENGINE = $engine;
-    eval "use $ENGINE";
-    die "Unable to load session engine `$ENGINE': $@" if $@;
-    engine->init();
-}
-
-sub get { get_current_session() }
-
 # This wrapper look for the session engine and try to load it.
 sub init {
-    my ($class, $setting) = @_;
+    my ($class, $name, $config) = @_;
+    $ENGINE = Dancer::Engine->build(session => $name, $config);
 
-    (exists $ENGINES->{$setting}) 
-        ? set_engine($ENGINES->{$setting})
-        : die "unsupported session engine: `$setting'";
+    #$ENGINE->init(); already done
 }
 
-# retreive or create a session for the client
+# retrieve or create a session for the client
 sub get_current_session {
-    my $sid = engine->read_session_id;
+    my $sid     = engine->read_session_id;
     my $session = undef;
+    my $class   = ref(engine);
 
-    $session = engine->retreive($sid) if $sid;
+    $session = $class->retrieve($sid) if $sid;
 
     if (not defined $session) {
-        $session = engine->create();
-        Dancer::Logger->debug("new session created => ".$session->id);
+        $session = $class->create();
         engine->write_session_id($session->id);
     }
     return $session;
 }
 
+sub get { get_current_session() }
+
 sub read {
     my ($class, $key) = @_;
     my $session = get_current_session();
@@ -60,7 +45,7 @@ sub write {
     my ($class, $key, $value) = @_;
     my $session = get_current_session();
     $session->{$key} = $value;
-    
+
     # TODO : should be moved as an "after" filter
     $session->flush;
     return $value;
@@ -68,6 +53,7 @@ sub write {
 
 1;
 __END__
+
 =pod
 
 =head1 NAME
@@ -76,9 +62,9 @@ Dancer::Session - session engine for the Dancer framework
 
 =head1 DESCRIPTION
 
-This module provides support for server-side session for the Dancer micro
+This module provides support for server-side sessions for the L<Dancer> web
 framework. The session is accessible to the user via an abstraction layer
-implemented by the Dancer::Session class.
+implemented by the L<Dancer::Session> class.
 
 =head1 USAGE
 
@@ -90,11 +76,11 @@ be done like the following:
 In the application code:
 
     # enabling the YAML-file-based session engine
-    set session => 'yaml';
+    set session => 'YAML';
 
 Or in config.yml or environments/$env.yml
 
-    session: "yaml"
+    session: "YAML"
 
 By default session are disabled, you must enable them before using it. If the
 session engine is disabled, any Dancer::Session call will throw an exception.
@@ -109,7 +95,7 @@ You can either look for an existing item in the session storage or modify one.
 Here is a simple example of two route handlers that implement a basic C</login> and
 C</home> actions using the session engine. 
 
-    post '/login' => {
+    post '/login' => sub {
         # look for params and authenticate the user
         # ...
         if ($user) {
@@ -117,7 +103,7 @@ C</home> actions using the session engine.
         }
     };
 
-    get '/home' => {
+    get '/home' => sub {
         # if a user is present in the session, let him go, otherwise redirect to
         # /login
         if (not session('user_id')) {
@@ -125,6 +111,12 @@ C</home> actions using the session engine.
         }
     };
 
+Of course, you probably don't want to have to duplicate the code to check
+whether the user is logged in for each route handler; there's an example in the
+L<Dancer::Cookbook> showing how to use a before filter to check whether the user
+is logged in before all requests, and redirect to a login page if not.
+
+
 =head1 SUPPORTED ENGINES
 
 Dancer has a modular session engine that makes implementing new session backends
@@ -140,6 +132,16 @@ The following engines are supported:
 A YAML file-based session backend, pretty convininent for development purposes,
 but maybe not the best for production needs.
 
+=item L<Dancer::Session::Memcached>
+
+Session are stored in Memcached servers. This is good for production matters
+and is a good way to use a distributed session storage.
+
+=item L<Dancer::Session::Cookie>
+
+This module implements a session engine for sessions stored entirely
+inside encrypted cookies (this engine doesn't use a server-side storage).
+
 =back
 
 =head1 DEPENDENCY
